summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/tools/tqglist.h
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/tools/tqglist.h')
-rw-r--r--tqtinterface/qt4/src/tools/tqglist.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/tqtinterface/qt4/src/tools/tqglist.h b/tqtinterface/qt4/src/tools/tqglist.h
index 4c91453..ebbd616 100644
--- a/tqtinterface/qt4/src/tools/tqglist.h
+++ b/tqtinterface/qt4/src/tools/tqglist.h
@@ -91,7 +91,7 @@ protected:
bool removeFirst(); // remove first item
bool removeLast(); // remove last item
bool removeAt( uint ); // remove item at i'th position
- bool tqreplaceAt( uint, TQPtrCollection::Item ); // tqreplace item at position i with item
+ bool replaceAt( uint, TQPtrCollection::Item ); // replace item at position i with item
TQPtrCollection::Item takeNode( TQLNode * ); // take out node
TQPtrCollection::Item take(); // take out current item
TQPtrCollection::Item takeAt( uint index ); // take out item at i'th pos
@@ -101,11 +101,11 @@ protected:
void sort(); // sort all items;
void clear(); // remove all items
- int tqfindRef( TQPtrCollection::Item, bool = TRUE ); // tqfind exact item in list
- int tqfind( TQPtrCollection::Item, bool = TRUE ); // tqfind equal item in list
+ int findRef( TQPtrCollection::Item, bool = TRUE ); // find exact item in list
+ int find( TQPtrCollection::Item, bool = TRUE ); // find equal item in list
- uint tqcontainsRef( TQPtrCollection::Item ) const; // get number of exact matches
- uint tqcontains( TQPtrCollection::Item ) const; // get number of equal matches
+ uint containsRef( TQPtrCollection::Item ) const; // get number of exact matches
+ uint contains( TQPtrCollection::Item ) const; // get number of equal matches
TQPtrCollection::Item at( uint index ); // access item at i'th pos
int at() const; // get current index